@@ -1,5 +1,5 @@
 __title__ = "colorgb"
-__version__ = "2.0"
+__version__ = "3.0"
 __authors__ = "LyQuid"
 __license__ = "MIT License"
 __copyright__ = "Copyright 2022-present LyQuid"
@@ -12,5 +12,6 @@ except ImportError:
 init()
 
 from .foregrounds import fore
-from .backrounds import bg
+from .backgrounds import bg
 from .styles import style
+from .special import blink
